@@ -49,10 +49,10 @@ def score_hub(adata,
     '''
     
     
-    cdata = adata.copy()
+    #cdata = adata.copy()
     
     np.random.seed(0)
-    var_names = cdata.var_names
+    var_names = adata.var_names
     
     
     
@@ -98,7 +98,7 @@ def score_hub(adata,
     
     #densify to make amplification faster
     try:
-        cdata.X = cdata.X.toarray() #faster but more memory
+        adata.X = adata.X.toarray() #faster but more memory
     except:
         pass
     
@@ -108,7 +108,7 @@ def score_hub(adata,
     ######## time to select background genes ########
     
     #get mean expression for each gene
-    gene_exp_avg = pd.Series(np.nanmean(cdata.X, axis=0), index = cdata.var_names)
+    gene_exp_avg = pd.Series(np.nanmean(adata.X, axis=0), index = adata.var_names)
     gene_exp_avg = gene_exp_avg[np.isfinite(gene_exp_avg)] #sometimes data missing?
     
     
@@ -141,15 +141,15 @@ def score_hub(adata,
     
     ### binarize
     if binarize:
-        cdata.X[cdata.X > 0] = 1
+        adata.X[adata.X > 0] = 1
         
     
     
     #### amplify expression matrix by gene importance
     if importance:
         for gene, importance in hub:
-            i = np.where(cdata.var_names == gene)[0][0]
-            cdata.X[:,i] = cdata.X[:,i] * importance
+            i = np.where(adata.var_names == gene)[0][0]
+            adata.X[:,i] = adata.X[:,i] * importance
         
         
         
@@ -157,12 +157,12 @@ def score_hub(adata,
      #### time to get scores ####
 
     #mean for input genes for each cell
-    X_list = cdata[:, present_genes].X #cells X input genes matrix
+    X_list = adata[:, present_genes].X #cells X input genes matrix
     X_list = np.nanmean(X_list, axis=1, dtype='float64')
 
     #X_control is mean of control genes for each cell
     control_genes = list(control_genes - set(present_genes))
-    X_control = cdata[:, control_genes].X #cells X control genes
+    X_control = adata[:, control_genes].X #cells X control genes
     X_control = np.nanmean(X_control, axis=1, dtype='float64')
         
     
@@ -242,7 +242,7 @@ def score_all_cells(adata,
     for idents in tqdm(unique_combos.values):
         
         #subset adata based on identifiers. For each id, keep only those
-        c_sub = adata.copy()
+        c_sub = adata
         for x, ident in enumerate(identifiers):
             c_sub = c_sub[c_sub.obs[ident] == idents[x]]
         
